from confluent_kafka import Consumer, KafkaException
import json

# Create Confluent Kafka consumer
consumer = Consumer({
    'bootstrap.servers': 'localhost:9092',
    'group.id': 'my-group',
    'auto.offset.reset': 'earliest'
})

# Subscribe to 'sensor-data' topic
consumer.subscribe(['sensor-data'])

# Consume messages from 'sensor-data' topic
try:
    while True:
        msg = consumer.poll(1.0)  # Poll for messages with a timeout of 1 second

        if msg is None:
            continue
        if msg.error():
            if msg.error().code() == KafkaError._PARTITION_EOF:
                # End of partition event
                print(f"{msg.topic()} [{msg.partition()}] reached end at offset {msg.offset()}")
            elif msg.error():
                raise KafkaException(msg.error())
        else:
            # Proper message
            sensor_data = json.loads(msg.value().decode('utf-8'))  # Deserialize the JSON data
            print(f"Received: {sensor_data}")
            # You can process the data here (e.g., analyze, store in a DB)
except KeyboardInterrupt:
    print("Stopped by user")
finally:
    # Close down consumer to commit final offsets.
    consumer.close()