from confluent_kafka import Producer
import random
import json
import time

# Delivery report callback
def delivery_report(err, msg):
    if err is not None:
        print(f"Message delivery failed: {err}")
    else:
        print(f"Message delivered to {msg.topic()} [{msg.partition()}]")

# Create Confluent Kafka producer
producer = Producer({'bootstrap.servers': 'localhost:9092'})

# Generate random sensor data and send to 'sensor-data' topic
try:
    while True:
        sensor_data = {
            "sensor_id": random.randint(1, 10),  # Simulating sensor ID
            "temperature": random.uniform(20.0, 30.0),  # Random temperature value
            "humidity": random.uniform(30.0, 80.0)  # Random humidity value
        }
        
        # Send data to 'sensor-data' topic
        producer.produce('sensor-data', key=str(sensor_data["sensor_id"]), value=json.dumps(sensor_data), callback=delivery_report)
        producer.poll(0)  # Serve delivery callback queue
        
        time.sleep(2)  # Simulate data being sent every 2 seconds
except KeyboardInterrupt:
    print("Stopped by user")
finally:
    producer.flush()